@@ -12,19 +12,6 @@ lmfo <- lm_robust(y ~ z, data = dat, fixed_effects = ~ x)
 
 test_that("tidy, summary, and print work", {
 
-  expect_is(
-    tidy(NULL),
-    "data.frame"
-  )
-
-  # Might need to force this test of tidy.default
-
-  d <- date()
-  expect_warning(
-    estimatr:::tidy.default(d),
-    "using as.data.frame"
-  )
-
   ## lm_robust
   lmo <- lm_robust(y ~ x, data = dat, se_type = "classical")
 
